@@ -1,7 +1,7 @@
 package Dancer::Serializer::YAML;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer for handling YAML data
-$Dancer::Serializer::YAML::VERSION = '1.3205'; # TRIAL
+$Dancer::Serializer::YAML::VERSION = '1.3300'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -29,7 +29,7 @@ sub to_yaml {
 sub loaded { 
     my $module = Dancer::Config::settings->{engines}{YAML}{module} || 'YAML';
 
-    raise core_serializer => q{Dancer::Serializer::YAML only supports 'YAML' or 'YAML::XS', not $module}
+    raise core_serializer => q{Dancer::Serializer::YAML only support 'YAML' or 'YAML::XS', not $module}
         unless $module =~ /^YAML(?:::XS)?$/;
 
     Dancer::ModuleLoader->load($module) 
@@ -43,20 +43,12 @@ sub init {
 
 sub serialize {
     my ($self, $entity) = @_;
-    my $module = Dancer::Config::settings->{engines}{YAML}{module} || 'YAML';
-    {
-        no strict 'refs';
-        &{ $module . '::Dump' }($entity);
-    }
+    YAML::Dump($entity);
 }
 
 sub deserialize {
     my ($self, $content) = @_;
-    my $module = Dancer::Config::settings->{engines}{YAML}{module} || 'YAML';
-    {
-        no strict 'refs';
-        &{ $module . '::Load' }($content);
-    }
+    YAML::Load($content);
 }
 
 sub content_type {'text/x-yaml'}
@@ -75,7 +67,7 @@ Dancer::Serializer::YAML - serializer for handling YAML data
 
 =head1 VERSION
 
-version 1.3205
+version 1.3300
 
 =head1 SYNOPSIS
 
