@@ -1,7 +1,7 @@
 package Dancer::Session::Abstract;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: abstract class for session engine
-$Dancer::Session::Abstract::VERSION = '1.3205'; # TRIAL
+$Dancer::Session::Abstract::VERSION = '1.3300'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -104,23 +104,7 @@ sub read_session_id {
 
     my $name = $class->session_name();
     my $c    = Dancer::Cookies->cookies->{$name};
-    return unless defined $c;
-    if ($class->validate_session_id($c->value)) {
-        return $c->value;
-    } else {
-        warn "Rejecting invalid session ID ". $c->value;
-        return;
-    }
-}
-
-# Validate session ID (base64 chars plus hyphen by default) to avoid potential
-# issues, e.g. if the ID is used insecurely elsewhere.  If a session provider
-# expects more unusual IDs, it can override this class method with one that
-# validates according to that provider's expectation of how a session ID should
-# look.
-sub validate_session_id {
-    my ($class, $id) = @_;
-    return $id =~ m{^[A-Za-z0-9_\-~]+$};
+    return (defined $c && $c->value =~ /^\d+$/) ? $c->value : undef;
 }
 
 sub write_session_id {
@@ -160,7 +144,7 @@ Dancer::Session::Abstract - abstract class for session engine
 
 =head1 VERSION
 
-version 1.3205
+version 1.3300
 
 =head1 DESCRIPTION
 
@@ -257,7 +241,7 @@ Build a new uniq id.
 
 =item B<read_session_id>
 
-Reads the session ID from the cookie, ensuring it's syntactically valid.
+Reads the C<dancer.session> cookie.
 
 =item B<write_session_id>
 
